==> mars-0.9.2.tar.gz: mars-0.9.2/src/mpu/lib/mars_task.c <==
/*
 * Copyright 2008 Sony Corporation of America
 *
 *
 * Permission is hereby granted, free of charge, to any person obtaining
 * a copy of this Library and associated documentation files (the
 * "Library"), to deal in the Library without restriction, including
 * without limitation the rights to use, copy, modify, merge, publish,
 * distribute, sublicense, and/or sell copies of the Library, and to
 * permit persons to whom the Library is furnished to do so, subject to
 * the following conditions:
 *
 *  The above copyright notice and this permission notice shall be
 *  included in all copies or substantial portions of the Library.
 *
 *  If you modify the Library, you may copy and distribute your modified
 *  version of the Library in object code or as an executable provided
 *  that you also do one of the following:
 *
 *   Accompany the modified version of the Library with the complete
 *   corresponding machine-readable source code for the modified version
 *   of the Library; or,
 *
 *   Accompany the modified version of the Library with a written offer
 *   for a complete machine-readable copy of the corresponding source
 *   code of the modified version of the Library.
 *
 *
 * THE LIBRARY IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
 * EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
 * MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
 * IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY
 * CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
 * TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
 * LIBRARY OR THE USE OR OTHER DEALINGS IN THE LIBRARY.
 */

#include "mars/mars_task.h"
#include "mars/mars_task_types.h"
#include "mars/mars_syscalls.h"
#include "mars/mars_error.h"
#include "mars/mars_debug.h"

void mars_task_exit(void)
{
	mars_exit();
}

int mars_task_yield(void)
{
	struct mars_task_context *task;

	task = (struct mars_task_context *)mars_get_workload_context();

	/* make sure task context has a context save area */
	MARS_CHECK_RET(task->context_save_size && task->context_save_area,
			MARS_ERROR_FORMAT);

	mars_yield();

	return MARS_SUCCESS;
}

int mars_task_schedule(struct mars_task_id *id,
			struct mars_task_args *args,
			uint8_t priority)
{
	MARS_CHECK_RET(id, MARS_ERROR_NULL);

	return mars_schedule(id->workload_id, args, priority);
}

int mars_task_wait(struct mars_task_id *id)
{
	MARS_CHECK_RET(id, MARS_ERROR_NULL);

	int ret;
	struct mars_task_context *task;

	task = (struct mars_task_context *)mars_get_workload_context();

	/* make sure task context has a context save area */
	MARS_CHECK_RET(task->context_save_size && task->context_save_area,
			MARS_ERROR_FORMAT);

	ret = mars_wait(id->workload_id);
	MARS_CHECK_RET(ret == MARS_SUCCESS, ret);

	mars_signal_wait();

	return MARS_SUCCESS;
}

int mars_task_try_wait(struct mars_task_id *id)
{
	MARS_CHECK_RET(id, MARS_ERROR_NULL);

	return mars_try_wait(id->workload_id);
}

uint32_t mars_task_get_kernel_id(void)
{
	return mars_get_kernel_id();
}

const struct mars_task_id *mars_task_get_id(void)
{
	struct mars_task_context *task;

	task = (struct mars_task_context *)mars_get_workload_context();

	return &task->id;
}

const char *mars_task_get_name(void)
{
	struct mars_task_context *task;

	task = (struct mars_task_context *)mars_get_workload_context();

	return (const char *)task->id.name;
}

==> mars-08.06.26.tar.gz: mars-08.06.26/src/mpu/lib/mars_task.c <==
/*
 * Copyright 2008 Sony Corporation of America
 *
 *
 * Permission is hereby granted, free of charge, to any person obtaining
 * a copy of this Library and associated documentation files (the
 * "Library"), to deal in the Library without restriction, including
 * without limitation the rights to use, copy, modify, merge, publish,
 * distribute, sublicense, and/or sell copies of the Library, and to
 * permit persons to whom the Library is furnished to do so, subject to
 * the following conditions:
 *
 *  The above copyright notice and this permission notice shall be 
 *  included in all copies or substantial portions of the Library.
 *
 *  If you modify the Library, you may copy and distribute your modified 
 *  version of the Library in object code or as an executable provided 
 *  that you also do one of the following:
 *
 *   Accompany the modified version of the Library with the complete 
 *   corresponding machine-readable source code for the modified version 
 *   of the Library; or,
 *
 *   Accompany the modified version of the Library with a written offer 
 *   for a complete machine-readable copy of the corresponding source 
 *   code of the modified version of the Library.
 *
 *
 * THE LIBRARY IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
 * EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
 * MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
 * IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY
 * CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
 * TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
 * LIBRARY OR THE USE OR OTHER DEALINGS IN THE LIBRARY.
 */

#include "mars/mars_task.h"
#include "mars/mars_workload_types.h"
#include "mars/mars_syscalls.h"
#include "mars/mars_error.h"
#include "mars/mars_debug.h"

void mars_task_exit(void)
{
	mars_exit();
}

int mars_task_yield(void)
{
	struct mars_task_context *task;

	/* make sure task context has a context save area */
	task = &mars_get_workload_context()->type_context.task;
	MARS_CHECK_RET(task->context_save_size && task->context_save_area,
			MARS_ERROR_FORMAT);

	mars_yield();

	return MARS_SUCCESS;
}

int mars_task_schedule(struct mars_task_id *id,
			struct mars_task_args *args,
			uint8_t priority)
{
	MARS_CHECK_RET(id, MARS_ERROR_NULL);

	return mars_schedule(id->workload_id, args, priority);
}

int mars_task_wait(struct mars_task_id *id)
{
	MARS_CHECK_RET(id, MARS_ERROR_NULL);

	int ret;
	struct mars_task_context *task;

	/* make sure task context has a context save area */
	task = &mars_get_workload_context()->type_context.task;
	MARS_CHECK_RET(task->context_save_size && task->context_save_area,
			MARS_ERROR_FORMAT);

	ret = mars_wait(id->workload_id);
	MARS_CHECK_RET(ret == MARS_SUCCESS, ret);

	mars_signal_wait();

	return MARS_SUCCESS;
}

int mars_task_try_wait(struct mars_task_id *id)
{
	MARS_CHECK_RET(id, MARS_ERROR_NULL);

	return mars_try_wait(id->workload_id);
}

uint32_t mars_task_get_kernel_id(void)
{
	return mars_get_kernel_id();
}

const struct mars_task_id *mars_task_get_id(void)
{
	return &mars_get_workload_context()->type_context.task.id;
}

const char *mars_task_get_name(void)
{
	return (const char *)
		&mars_get_workload_context()->type_context.task.id.name;
}
